(user)=
# User
Welcome to the User section of the BEC Widgets documentation! BEC Widgets is a versatile GUI framework tailored for beamline scientists, enabling efficient and intuitive interaction with beamline experiments. This section is designed to guide both new and experienced users through the essential aspects of utilizing BEC Widgets.

```{toctree}
---
maxdepth: 2
hidden: true
---

getting_started/getting_started.md
applications/applications.md
widgets/widgets.md
api_reference/api_reference.md
```


***

````{grid} 2
:gutter: 5

```{grid-item-card}
:link: user.getting_started
:link-type: ref
:img-top: /assets/rocket_launch_48dp.svg
:text-align: center
:class-item: index-card

## Getting Started

Learn how to install BEC Widgets and get started with the framework.
```

```{grid-item-card}
:link: user.applications
:link-type: ref
:img-top: /assets/display_settings_48dp.svg
:text-align: center
:class-item: index-card

## Applications

Learn how to use BEC Widgets Applications, to modify and create new applications.

```

```{grid-item-card}
:link: user.widgets
:link-type: ref
:img-top: /assets/apps_48dp.svg
:text-align: center
:class-item: index-card

## Widgets

Learn about the building blocks of larger applications: widgets.
```

```{grid-item-card} 
:link: user.api_reference
:link-type: ref
:img-top: /assets/index_api.svg
:text-align: center
:class-item: index-card

## API reference

Comprehensive reference of all user-facing classes, functions, and methods.
```
````